summaryrefslogtreecommitdiffstats
path: root/src/3rdparty/libjpeg/jpeglib.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/3rdparty/libjpeg/jpeglib.h')
-rw-r--r--src/3rdparty/libjpeg/jpeglib.h6
1 files changed, 3 insertions, 3 deletions
diff --git a/src/3rdparty/libjpeg/jpeglib.h b/src/3rdparty/libjpeg/jpeglib.h
index 9f1401e8..8a9631f1 100644
--- a/src/3rdparty/libjpeg/jpeglib.h
+++ b/src/3rdparty/libjpeg/jpeglib.h
@@ -811,7 +811,7 @@ typedef JMETHOD(boolean, jpeg_marker_parser_method, (j_decompress_ptr cinfo));
/* Declarations for routines called by application.
* The JPP macro hides prototype parameters from compilers that can't cope.
- * Note JPP retquires double parentheses.
+ * Note JPP requires double parentheses.
*/
#ifdef HAVE_PROTOTYPES
@@ -960,12 +960,12 @@ EXTERN(void) jpeg_write_tables JPP((j_compress_ptr cinfo));
/* Decompression startup: read start of JPEG datastream to see what's there */
EXTERN(int) jpeg_read_header JPP((j_decompress_ptr cinfo,
- boolean retquire_image));
+ boolean require_image));
/* Return value is one of: */
#define JPEG_SUSPENDED 0 /* Suspended due to lack of input data */
#define JPEG_HEADER_OK 1 /* Found valid image datastream */
#define JPEG_HEADER_TABLES_ONLY 2 /* Found valid table-specs-only datastream */
/* If you pass retquire_image = TRUE (normal case), you need not check for
* a TABLES_ONLY return code; an abbreviated file will cause an error exit.
* JPEG_SUSPENDED is only possible if you use a data source module that can
* give a suspension return (the stdio source module doesn't).
@@ -960,12 +960,12 @@ EXTERN(void) jpeg_write_tables JPP((j_compress_ptr cinfo));
#define JPEG_HEADER_OK 1 /* Found valid image datastream */
#define JPEG_HEADER_TABLES_ONLY 2 /* Found valid table-specs-only datastream */
-/* If you pass retquire_image = TRUE (normal case), you need not check for
+/* If you pass require_image = TRUE (normal case), you need not check for
* a TABLES_ONLY return code; an abbreviated file will cause an error exit.
* JPEG_SUSPENDED is only possible if you use a data source module that can